@@ -636,8 +636,15 @@ impl Screen<'_> {
 
         let disambiguate = mode.contains(Mode::DISAMBIGUATE_ESC_CODES)
             && (key.logical_key == Key::Named(NamedKey::Escape)
-                || (!mods.is_empty() && mods != ModifiersState::SHIFT)
-                || key.location == KeyLocation::Numpad);
+                || key.location == KeyLocation::Numpad
+                || (!mods.is_empty()
+                    && (mods != ModifiersState::SHIFT
+                        || matches!(
+                            key.logical_key,
+                            Key::Named(NamedKey::Tab)
+                                | Key::Named(NamedKey::Enter)
+                                | Key::Named(NamedKey::Backspace)
+                        ))));
 
         match key.logical_key {
             _ if disambiguate => true,
@@ -1373,7 +1380,7 @@ impl Screen<'_> {
         let is_hyperlink_key_active = self.modifiers.state().super_key();
 
         #[cfg(not(target_os = "macos"))]
-        let is_hyperlink_key_active = self.modifiers.state().alt_key();
+        let is_hyperlink_key_active = self.modifiers.state().shift_key();
 
         if !is_hyperlink_key_active {
             return false;
@@ -1579,7 +1586,7 @@ impl Screen<'_> {
             .search_state
             .history
             .front()
-            .map_or(true, |regex| !regex.is_empty())
+            .is_none_or(|regex| !regex.is_empty())
         {
             self.search_state.history.push_front(String::new());
             self.search_state.history.truncate(MAX_SEARCH_HISTORY_SIZE);
@@ -2109,13 +2116,12 @@ impl Screen<'_> {
             None
         };
 
-        self.renderer.update(
+        self.renderer.run(
             &mut self.sugarloaf,
             &mut self.context_manager,
             &mut search_hints,
             &self.search_state.focused_match,
         );
-        self.sugarloaf.render();
         // In this case the configuration of blinking cursor is enabled
         // and the terminal also have instructions of blinking enabled
         // TODO: enable blinking for selection after adding debounce (https://github.com/raphamorim/rio/issues/437)
